The SIDD 1.0 GeographicAndTarget object
=======================================

.. automodule:: sarpy.io.product.sidd1_elements.GeographicAndTarget
    :members:
    :show-inheritance:
    :inherited-members:
